from .recaptcha_v2 import RecaptchaV2Task
from .fun_captcha import FuncaptchaTask
from .recaptcha_v3 import RecaptchaV3Task
from .hcaptcha import HCaptchaTask
from .image_to_text import ImageToTextTask
from .geetest import GeeTestTask
from .utils import CapmonsterException
